@@ -18,7 +18,6 @@ import math
 import datetime
 import forecast
 import noaa
-import time
 from collections import Counter
 from geopy import geocoders
 
@@ -35,7 +34,8 @@ class resultSet(object):
     def dump(self):
         return (self.timeseries, self.values)
     def dumps(self):
-        return ([int(time.mktime(i.timetuple())) for i in self.timeseries],self.values)
+        return ([int((i - datetime.datetime(1970,1,1)).total_seconds()) \
+                for i in self.timeseries],self.values)
 
     def plot(self):
         import matplotlib.pyplot as plt
