@@ -16,16 +16,20 @@ p1 = """{"system_name":"HAPPY CUSTOMER",
             ]}"""
 plant = pv.jsonToSystem(json.loads(p1))
 b = plant.forecastOutput(source = 'blave')
+print b.timeseries[0]
 print b.values
 print len(b.values)
 print  sum(b.values)
 
 f = plant.forecastOutput(source = 'forecast')
+print f.timeseries[0]
 print f.values
 print len(f.values)
 print  sum(f.values)
 
 n = plant.forecastOutput(source = 'noaa')
+print n.timeseries[0]
+
 print n.values
 print len(n.values)
 print  sum(n.values)
